Module impls

Module impls 

Implementations of the Schema trait for foreign crates

Each module requires the matching feature flag to be enabled.

Modules

builtins_nostd
Implementations of the Schema trait for core types
builtins_stduse-std
Implementations of the Schema trait for std types
chrono_v0_4chrono-v0_4
Implementations of the Schema trait for the chrono crate v0.4
fixed_v1_0fixed-v1_0
Implementations of the Schema trait for the fixed crate v1.0
heapless_v0_7heapless-v0_7
Implementations of the Schema trait for the heapless crate v0.7
heapless_v0_8heapless-v0_8
Implementations of the Schema trait for the heapless crate v0.8
heapless_v0_9heapless-v0_9
Implementations of the Schema trait for the heapless crate v0.9
nalgebra_v0_33nalgebra-v0_33
Implementations of the Schema trait for the nalgebra crate v0.33
serde_big_array_v0_5serde-big-array-v0_5
Implementations of the Schema trait for the serde-big-array crate v0.5.
uuid_v1_0uuid-v1_0
Implementations of the Schema trait for the uuid crate v1.0